from config import Config
import requests, json

class Quotes():

    def __init__(self):
        self._url = Config.get('URL', 'api_quotes')

    def get_quotes(self, quote = None):
        """
        Busca na API Challenge Quotes, as citações 'Zen of Python'.
        """
        if quote is not None:
            response = requests.get(self._url + f"/{quote}")
        else:
            response = requests.get(self._url)

        return response.json()

if __name__ == "__main__":
    q = Quotes()
    q.get_quotes()


from setuptools import setup

setup(
    name='zen_quotes',
    packages = ['quotes'],
    version='1.0.1',
    description='A sample lib Zen of Python',
    author='Yuri Mussi',
    author_email='ymussi@gmail.com',
    license='BSD',
    url='https://github.com/ymussi/zen_quotes',
    keywords = [],
    classifiers = [],
    )